==> AnVILPublish_1.0.0.zip: AnVILPublish/doc/AnVILPublishIntro.R <==
## -----------------------------------------------------------------------------
if (!"AnVILPublish" %in% rownames(installed.packages()))
    BiocManager::install("AnVILPublish")

## ---- eval = FALSE------------------------------------------------------------
#  AnVIL::gcloud_exists()

## ---- eval = FALSE------------------------------------------------------------
#  AnVIL::gcloud_account()
#  AnVIL::gcloud_project()

## ---- eval = FALSE------------------------------------------------------------
#  system2("notedown", "--version")

## ---- eval = FALSE------------------------------------------------------------
#  AnVILPublish::as_workspace(
#      "path/to/package",
#      "bioconductor-rpci-anvil",     # i.e., billing account
#      create = TRUE                  # use update = TRUE for an existing workspace
#  )

## ---- eval = FALSE------------------------------------------------------------
#  AnVILPublish::as_workspace(
#      "path/to/directory",      # directory containing DESCRIPTION file
#      "bioconductor-rpci-anvil",
#      create = TRUE
#  )

## ---- eval = FALSE------------------------------------------------------------
#  AnVIL::Publish::as_notebook(
#      "paths/to/files.Rmd",
#      "bioconductor-rpci-anvil",     # i.e., billing account
#      "Bioconductor-Package-Foo",    # Workspace name
#      update = FALSE                 # make notebooks, but do not update workspace
#  )

## ---- eval = FALSE------------------------------------------------------------
#  AnVILPublish::add_access(
#      "bioconductor-rpci-anvil",
#      "Bioconductor-Package-Foo"
#  )

## ---- eval = FALSE------------------------------------------------------------
#  knitr::opts_chunk$set(eval=FALSE)
#  rmarkdown::render(..., md_document())

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

==> AnVILPublish_1.6.0.zip: AnVILPublish/doc/AnVILPublishIntro.R <==
## -----------------------------------------------------------------------------
if (!"AnVILPublish" %in% rownames(installed.packages()))
    BiocManager::install("AnVILPublish")

## ---- eval = FALSE------------------------------------------------------------
#  AnVIL::gcloud_exists()

## ---- eval = FALSE------------------------------------------------------------
#  AnVIL::gcloud_account()
#  AnVIL::gcloud_project()

## ---- eval = FALSE------------------------------------------------------------
#  system2("notedown", "--version")

## ---- eval = FALSE------------------------------------------------------------
#  AnVILPublish::as_workspace(
#      "path/to/package",
#      "bioconductor-rpci-anvil",     # i.e., billing account
#      create = TRUE                  # use update = TRUE for an existing workspace
#  )

## ---- eval = FALSE------------------------------------------------------------
#  AnVILPublish::as_workspace(
#      "path/to/directory",      # directory containing DESCRIPTION file
#      "bioconductor-rpci-anvil",
#      create = TRUE
#  )

## ---- eval = FALSE------------------------------------------------------------
#  AnVILPublish::as_notebook(
#      "paths/to/files.Rmd",
#      "bioconductor-rpci-anvil",     # i.e., billing account
#      "Bioconductor-Package-Foo",    # Workspace name
#      update = FALSE                 # make notebooks, but do not update workspace
#  )

## ---- eval = FALSE------------------------------------------------------------
#  AnVILPublish::add_access(
#      "bioconductor-rpci-anvil",
#      "Bioconductor-Package-Foo"
#  )

## ---- eval = FALSE------------------------------------------------------------
#  knitr::opts_chunk$set(eval=FALSE)
#  rmarkdown::render(..., md_document())

## ----sessionInfo--------------------------------------------------------------
sessionInfo()
